FconfigAnnotationField class

定义 FconfigAnnotationField 类,用于配置注解字段。

Annotations
  • @Target.new({TargetKind.field})

Constructors

FconfigAnnotationField()
构造 FconfigAnnotationField 实例,使用 const 修饰以支持常量构造。
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited